@@ -1,4 +1,5 @@
 from __future__ import annotations
+from copy import deepcopy
 from shapely.wkt import loads as wkt_loads
 from shapely.geometry import GeometryCollection
 from papermodels.datatypes.annotation import Annotation
@@ -77,7 +78,8 @@ def scale_annotations(
     """
     scaled_annotations = []
     for annot in annots:
-        scaled_annotations.append(scale_annotation(annot, scale, paper_origin))
+        new_annot = deepcopy(annot)
+        scaled_annotations.append(scale_annotation(new_annot, scale, paper_origin))
     return scaled_annotations
 
 
